@@ -2,7 +2,11 @@
 #include <stdint.h>
 #include <stddef.h>
 #include <cstring>
-#include <panda/lib/def.h>
+
+namespace panda {
+    inline bool likely   (bool expr) { return __builtin_expect(expr,1); }
+    inline bool unlikely (bool expr) { return __builtin_expect(expr,0); }
+};
 
 namespace panda { namespace lib {
 
