@@ -3,13 +3,14 @@
 #include <exception>
 #include <panda/string.h>
 
-#define PXS_TRY(code)                                                                         \
+#define PXS_TRY(code) {                                                                       \
     try { code; }                                                                             \
     catch (const std::exception& err) { croak_sv(xs::lib::error_sv(err)); }                   \
     catch (const char* err)           { croak_sv(newSVpv(err, 0)); }                          \
     catch (const std::string& err)    { croak_sv(newSVpvn(err.c_str(), err.length())); }      \
     catch (const panda::string& err)  { croak_sv(newSVpvn(err.c_str(), err.length())); }      \
-    catch (...)                       { croak_sv(newSVpvs("unknown c++ exception thrown")); }
+    catch (...)                       { croak_sv(newSVpvs("unknown c++ exception thrown")); } \
+}
 
 namespace xs { namespace lib {
 
